# Custom Reports
Learn how to build custom reports tailored to your organization's needs.
SAP LeanIX offers a wide range of standard, ready-to-use reports that enable you to visualize and analyze data. To learn more about using reports, see [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD).
While standard reports cater to a broad range of requirements, there may be specific use cases that benefit from a more customized approach. For example, your organization may need reports that are tailored to your particular domain or industry.
As a developer, you can build custom reports using the [Reporting Framework and CLI](https://help.sap.com/docs/leanix/ea/reporting-framework-and-cli?locale=en-US&state=PRODUCTION&version=CLOUD "Build custom reports using the LeanIX Reporting Framework and CLI."). This toolkit enables you to connect to your SAP LeanIX workspace, retrieve data, build reports, and then upload them to your workspace or publish them on the SAP LeanIX Store.
In this section, you'll learn how to:
  * Build custom reports in various formats
  * Query data for reports
  * Visualize report data
  * Upload reports to your workspace or publish them on the SAP LeanIX Store
